package com.ruoyi.warehouseBusiness.service;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.warehouseBusiness.domain.TWarehousebillsModify;
import com.ruoyi.warehouseBusiness.domain.dto.WarehousebillsModifyDTO;
import com.ruoyi.warehouseBusiness.domain.vo.WarehousebillsModifyVO;

import java.util.List;

/**
 * 仓库费用变更主表Service接口
 *
 * @author ruoyi
 * @date 2021-10-27
 */
public interface ITWarehousebillsModifyService {
    /**
     * 查询仓库主(出入库)
     *
     * @param fId 仓库主(出入库)ID
     * @return 仓库主(出入库)
     */
    public WarehousebillsModifyVO selectTWarehousebillsModifyById(Long fId);

    /**
     * 查询仓库主(出入库)列表
     *
     * @param warehousebillsModifyDto 仓库主(出入库)
     * @return 仓库主(出入库)集合
     */
    public List<TWarehousebillsModify> selectTWarehousebillsModifyList(WarehousebillsModifyDTO warehousebillsModifyDto);

    /**
     * 新增仓库主(出入库)
     *
     * @param tWarehousebillsModify 仓库主(出入库)
     * @return 结果
     */
    public AjaxResult submitTWarehousebillsModify(WarehousebillsModifyDTO tWarehousebillsModify);

    /**
     * 修改仓库主(出入库)
     *
     * @param tWarehousebillsModify 仓库主(出入库)
     * @return 结果
     */
    public AjaxResult saveTWarehousebillsModify(WarehousebillsModifyDTO tWarehousebillsModify);

    /**
     * 批量删除仓库主(出入库)
     *
     * @param fIds 需要删除的仓库主(出入库)ID
     * @return 结果
     */
    public AjaxResult deleteTWarehousebillsModifyByIds(String fIds);

    /**
     * 删除仓库主(出入库)信息
     *
     * @param fId 仓库主(出入库)ID
     * @return 结果
     */
    public int deleteTWarehousebillsModifyById(Long fId);

    /**
     * 根据仓库id、费用类型查询费用信息
     *
     * @param fId  仓库id
     * @param type 费用类型
     * @return
     */
    AjaxResult selectTWarehousebillsFeesById(Long fId, String type);

    /**
     * 已经审核完成，要撤回
     *
     * @param id 主表id
     * @return
     */
    AjaxResult revokeReviewedById(Long id);
}
